# Generated by Django 2.2.19 on 2021-05-05 14:34

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='VAPIDKeyset',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('_private_key', models.BinaryField(max_length=43)),
            ],
        ),
    ]
